from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.taxonomy import topic_pb2 as _topic_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateTopicInput(_message.Message):
    __slots__ = ["topic"]
    TOPIC_FIELD_NUMBER: _ClassVar[int]
    topic: _topic_pb2.Topic
    def __init__(self, topic: _Optional[_Union[_topic_pb2.Topic, _Mapping]] = ...) -> None: ...

class CreateTopicOutput(_message.Message):
    __slots__ = ["topic_id"]
    TOPIC_ID_FIELD_NUMBER: _ClassVar[int]
    topic_id: str
    def __init__(self, topic_id: _Optional[str] = ...) -> None: ...

class DeleteTopicInput(_message.Message):
    __slots__ = ["topic_id"]
    TOPIC_ID_FIELD_NUMBER: _ClassVar[int]
    topic_id: str
    def __init__(self, topic_id: _Optional[str] = ...) -> None: ...

class DeleteTopicOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteTranslationInput(_message.Message):
    __slots__ = ["locale", "topic_id"]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    TOPIC_ID_FIELD_NUMBER: _ClassVar[int]
    locale: str
    topic_id: str
    def __init__(self, topic_id: _Optional[str] = ..., locale: _Optional[str] = ...) -> None: ...

class DeleteTranslationOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeTopicInput(_message.Message):
    __slots__ = ["locale", "topic_id"]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    TOPIC_ID_FIELD_NUMBER: _ClassVar[int]
    locale: str
    topic_id: str
    def __init__(self, topic_id: _Optional[str] = ..., locale: _Optional[str] = ...) -> None: ...

class DescribeTopicOutput(_message.Message):
    __slots__ = ["topic"]
    TOPIC_FIELD_NUMBER: _ClassVar[int]
    topic: _topic_pb2.Topic
    def __init__(self, topic: _Optional[_Union[_topic_pb2.Topic, _Mapping]] = ...) -> None: ...

class ListTopicsInput(_message.Message):
    __slots__ = ["filters", "locale", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["id", "name", "query"]
        ID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        QUERY_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        name: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        query: str
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., name: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListTopicsInput.Filter
    locale: str
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListTopicsInput.Filter, _Mapping]] = ..., locale: _Optional[str] = ...) -> None: ...

class ListTopicsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_topic_pb2.Topic]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_topic_pb2.Topic, _Mapping]]] = ...) -> None: ...

class ListTranslationsInput(_message.Message):
    __slots__ = ["filters", "offset", "size", "topic_id"]
    class Filter(_message.Message):
        __slots__ = ["locale"]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        locale: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, locale: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    TOPIC_ID_FIELD_NUMBER: _ClassVar[int]
    filters: ListTranslationsInput.Filter
    offset: int
    size: int
    topic_id: str
    def __init__(self, topic_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListTranslationsInput.Filter, _Mapping]] = ...) -> None: ...

class ListTranslationsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_topic_pb2.Topic.Translation]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_topic_pb2.Topic.Translation, _Mapping]]] = ...) -> None: ...

class TranslateTopicInput(_message.Message):
    __slots__ = ["locale", "topic_id", "translation"]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    TOPIC_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    locale: str
    topic_id: str
    translation: _topic_pb2.Topic.Translation
    def __init__(self, topic_id: _Optional[str] = ..., locale: _Optional[str] = ..., translation: _Optional[_Union[_topic_pb2.Topic.Translation, _Mapping]] = ...) -> None: ...

class TranslateTopicOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateTopicInput(_message.Message):
    __slots__ = ["patch", "topic", "topic_id"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ALL: UpdateTopicInput.Patch
    KEYWORDS: UpdateTopicInput.Patch
    NAME: UpdateTopicInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    SUMMARY: UpdateTopicInput.Patch
    TOPIC_FIELD_NUMBER: _ClassVar[int]
    TOPIC_ID_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[UpdateTopicInput.Patch]
    topic: _topic_pb2.Topic
    topic_id: str
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateTopicInput.Patch, str]]] = ..., topic_id: _Optional[str] = ..., topic: _Optional[_Union[_topic_pb2.Topic, _Mapping]] = ...) -> None: ...

class UpdateTopicOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Message(_message.Message):
    __slots__ = ["edited_at", "id", "member_id", "message", "posted_at", "reply_count", "reply_to", "thread_id", "vote", "vote_count"]
    EDITED_AT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    POSTED_AT_FIELD_NUMBER: _ClassVar[int]
    REPLY_COUNT_FIELD_NUMBER: _ClassVar[int]
    REPLY_TO_FIELD_NUMBER: _ClassVar[int]
    THREAD_ID_FIELD_NUMBER: _ClassVar[int]
    VOTE_COUNT_FIELD_NUMBER: _ClassVar[int]
    VOTE_FIELD_NUMBER: _ClassVar[int]
    edited_at: _timestamp_pb2.Timestamp
    id: str
    member_id: str
    message: _content_pb2.Content
    posted_at: _timestamp_pb2.Timestamp
    reply_count: int
    reply_to: str
    thread_id: str
    vote: int
    vote_count: int
    def __init__(self, id: _Optional[str] = ..., thread_id: _Optional[str] = ..., member_id: _Optional[str] = ..., reply_to: _Optional[str] = ..., vote: _Optional[int] = ..., vote_count: _Optional[int] = ..., reply_count: _Optional[int] = ..., posted_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., edited_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., message: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/judge.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.judge import activity_pb2 as eolymp_dot_judge_dot_activity__pb2
from eolymp.judge import announcement_pb2 as eolymp_dot_judge_dot_announcement__pb2
from eolymp.judge import contest_pb2 as eolymp_dot_judge_dot_contest__pb2
from eolymp.judge import participant_pb2 as eolymp_dot_judge_dot_participant__pb2
from eolymp.judge import problem_pb2 as eolymp_dot_judge_dot_problem__pb2
from eolymp.judge import reply_pb2 as eolymp_dot_judge_dot_reply__pb2
from eolymp.judge import result_pb2 as eolymp_dot_judge_dot_result__pb2
from eolymp.judge import score_pb2 as eolymp_dot_judge_dot_score__pb2
from eolymp.judge import submission_pb2 as eolymp_dot_judge_dot_submission__pb2
from eolymp.judge import template_pb2 as eolymp_dot_judge_dot_template__pb2
from eolymp.judge import ticket_pb2 as eolymp_dot_judge_dot_ticket__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x65olymp/judge/judge.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1b\x65olymp/judge/activity.proto\x1a\x1f\x65olymp/judge/announcement.proto\x1a\x1a\x65olymp/judge/contest.proto\x1a\x1e\x65olymp/judge/participant.proto\x1a\x1a\x65olymp/judge/problem.proto\x1a\x18\x65olymp/judge/reply.proto\x1a\x19\x65olymp/judge/result.proto\x1a\x18\x65olymp/judge/score.proto\x1a\x1d\x65olymp/judge/submission.proto\x1a\x1b\x65olymp/judge/template.proto\x1a\x19\x65olymp/judge/ticket.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"<\n\x12\x43reateContestInput\x12&\n\x07\x63ontest\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Contest\")\n\x13\x43reateContestOutput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"(\n\x12\x44\x65leteContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteContestOutput\"P\n\x12UpdateContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12&\n\x07\x63ontest\x18\x02 \x01(\x0b\x32\x15.eolymp.judge.Contest\"\x15\n\x13UpdateContestOutput\"*\n\x14\x44\x65scribeContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"?\n\x15\x44\x65scribeContestOutput\x12&\n\x07\x63ontest\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Contest\"!\n\x12LookupContestInput\x12\x0b\n\x03key\x18\x01 \x01(\t\"s\n\x13LookupContestOutput\x12&\n\x07\x63ontest\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Contest\x12\x34\n\nappearance\x18\x02 \x01(\x0b\x32 .eolymp.judge.Contest.Appearance\"\x8e\x04\n\x11ListContestsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.judge.ListContestsInput.Filter\x1a\xa1\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12-\n\x03own\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x38\n\tstarts_at\x18\x04 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x36\n\x07\x65nds_at\x18\x05 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x30\n\x06public\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x34\n\nvisibility\x18\x07 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06\x66ormat\x18\x08 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"I\n\x12ListContestsOutput\x12$\n\x05items\x18\x01 \x03(\x0b\x32\x15.eolymp.judge.Contest\x12\r\n\x05total\x18\x02 \x01(\x05\"&\n\x10OpenContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x13\n\x11OpenContestOutput\"\'\n\x11\x43loseContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x14\n\x12\x43loseContestOutput\")\n\x13SuspendContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x16\n\x14SuspendContestOutput\"(\n\x12\x46reezeContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x15\n\x13\x46reezeContestOutput\"(\n\x12ResumeContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x15\n\x13ResumeContestOutput\"&\n\x10JoinContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x13\n\x11JoinContestOutput\"\'\n\x11StartContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x14\n\x12StartContestOutput\"\x7f\n\x12ImportProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\timport_id\x18\x02 \x01(\t\x12\r\n\x05index\x18\n \x01(\r\x12\x14\n\x0csubmit_limit\x18\x0b \x01(\r\x12\x1d\n\x15score_by_best_testset\x18\x0c \x01(\x08\")\n\x13ImportProblemOutput\x12\x12\n\nproblem_id\x18\x02 \x01(\t\":\n\x10SyncProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"\x13\n\x11SyncProblemOutput\"\x80\x01\n\x12UpdateProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\r\n\x05index\x18\n \x01(\r\x12\x14\n\x0csubmit_limit\x18\x0b \x01(\r\x12\x1d\n\x15score_by_best_testset\x18\x0c \x01(\x08\"\x15\n\x13UpdateProblemOutput\"<\n\x12\x44\x65leteProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteProblemOutput\"<\n\x12RetestProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"\x15\n\x13RetestProblemOutput\"E\n\x11ListProblemsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"I\n\x12ListProblemsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.judge.Problem\"T\n\x14\x44\x65scribeProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x14\n\x0bproblem_ern\x18\x8fN \x01(\t\"?\n\x15\x44\x65scribeProblemOutput\x12&\n\x07problem\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Problem\"=\n\x13ListStatementsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"U\n\x14ListStatementsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12.\n\x05items\x18\x02 \x03(\x0b\x32\x1f.eolymp.judge.Problem.Statement\">\n\x14ListAttachmentsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"W\n\x15ListAttachmentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12/\n\x05items\x18\x02 \x03(\x0b\x32 .eolymp.judge.Problem.Attachment\";\n\x11ListExamplesInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"N\n\x12ListExamplesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12)\n\x05items\x18\x02 \x03(\x0b\x32\x1a.eolymp.judge.Problem.Test\"f\n\x13\x41\x64\x64ParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1a\n\x12out_of_competition\x18\x04 \x01(\x08\".\n\x14\x41\x64\x64ParticipantOutput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"D\n\x16\x45nableParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"\x19\n\x17\x45nableParticipantOutput\"E\n\x17\x44isableParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"\x1a\n\x18\x44isableParticipantOutput\"\x81\x02\n\x16UpdateParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12\x39\n\x05patch\x18\x03 \x01(\x0e\x32*.eolymp.judge.UpdateParticipantInput.Patch\x12\x0c\n\x04name\x18\n \x01(\t\x12\x12\n\nbonus_time\x18\x0c \x01(\r\x12\x1a\n\x12out_of_competition\x18\x0b \x01(\x08\"B\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x0e\n\nBONUS_TIME\x10\x03\x12\x16\n\x12OUT_OF_COMPETITION\x10\x04\"\x19\n\x17UpdateParticipantOutput\"D\n\x16RemoveParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"\x19\n\x17RemoveParticipantOutput\")\n\x13VerifyPasscodeInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"7\n\x14VerifyPasscodeOutput\x12\x10\n\x08required\x18\x01 \x01(\x08\x12\r\n\x05valid\x18\x02 \x01(\x08\":\n\x12\x45nterPasscodeInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x10\n\x08passcode\x18\x02 \x01(\t\"\x15\n\x13\x45nterPasscodeOutput\"@\n\x12ResetPasscodeInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"\'\n\x13ResetPasscodeOutput\x12\x10\n\x08passcode\x18\x01 \x01(\t\"P\n\x10SetPasscodeInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12\x10\n\x08passcode\x18\x03 \x01(\t\"\x13\n\x11SetPasscodeOutput\"A\n\x13RemovePasscodeInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"\x16\n\x14RemovePasscodeOutput\"\xe8\x05\n\x15ListParticipantsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.judge.ListParticipantsInput.Filter\x12:\n\x04sort\x18\x32 \x01(\x0e\x32,.eolymp.judge.ListParticipantsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\xa8\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x08 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x30\n\x06status\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x05score\x18\x04 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x32\n\x07penalty\x18\x05 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x39\n\nstarted_at\x18\x06 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12:\n\x0b\x63omplete_at\x18\x07 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\"M\n\x08Sortable\x12\x08\n\x04RANK\x10\x00\x12\t\n\x05SCORE\x10\x01\x12\x0b\n\x07PENALTY\x10\x02\x12\x0e\n\nSTARTED_AT\x10\x03\x12\x0f\n\x0b\x43OMPLETE_AT\x10\x04\"Q\n\x16ListParticipantsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.judge.Participant\"0\n\x1aIntrospectParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"M\n\x1bIntrospectParticipantOutput\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\"F\n\x18\x44\x65scribeParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"K\n\x19\x44\x65scribeParticipantOutput\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\"]\n\x15\x43reateSubmissionInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x0c\n\x04lang\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\"/\n\x16\x43reateSubmissionOutput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"\xe4\x04\n\x14ListSubmissionsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.judge.ListSubmissionsInput.Filter\x1a\xdd\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x36\n\x0eparticipant_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\nproblem_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06status\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12.\n\x04lang\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x05score\x18\x06 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x35\n\npercentage\x18\x07 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12;\n\x0csubmitted_at\x18\x08 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x33\n\tsignature\x18\t \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"O\n\x15ListSubmissionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.judge.Submission\"D\n\x17\x44\x65scribeSubmissionInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\"H\n\x18\x44\x65scribeSubmissionOutput\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.judge.Submission\"B\n\x15RetestSubmissionInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\"\x18\n\x16RetestSubmissionOutput\"B\n\x15\x44\x65leteSubmissionInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\"\x18\n\x16\x44\x65leteSubmissionOutput\"C\n\x16RestoreSubmissionInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\"\x19\n\x17RestoreSubmissionOutput\"I\n\x11\x43reateTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"\'\n\x12\x43reateTicketOutput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"9\n\x10\x43loseTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tticket_id\x18\x02 \x01(\t\"\x13\n\x11\x43loseTicketOutput\"8\n\x0fOpenTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tticket_id\x18\x02 \x01(\t\"\x12\n\x10OpenTicketOutput\"8\n\x0fReadTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tticket_id\x18\x02 \x01(\t\"\x12\n\x10ReadTicketOutput\":\n\x11\x44\x65leteTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tticket_id\x18\x02 \x01(\t\"\x14\n\x12\x44\x65leteTicketOutput\"<\n\x13\x44\x65scribeTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tticket_id\x18\x02 \x01(\t\"<\n\x14\x44\x65scribeTicketOutput\x12$\n\x06ticket\x18\x01 \x01(\x0b\x32\x14.eolymp.judge.Ticket\"\x96\x05\n\x10ListTicketsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x36\n\x07\x66ilters\x18( \x01(\x0b\x32%.eolymp.judge.ListTicketsInput.Filter\x12\x35\n\x04sort\x18\x32 \x01(\x0e\x32\'.eolymp.judge.ListTicketsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\x80\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\ncontest_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x36\n\x0eparticipant_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12@\n\x16is_read_by_participant\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12:\n\x10is_read_by_owner\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x31\n\x07is_open\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12-\n\x03own\x18\x07 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"F\n\x08Sortable\x12\x0e\n\nCREATED_AT\x10\x00\x12\x11\n\rREAD_BY_OWNER\x10\x01\x12\x17\n\x13READ_BY_PARTICIPANT\x10\x02\"G\n\x11ListTicketsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.judge.Ticket\"E\n\x10ReplyTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\n \x01(\t\x12\r\n\x05\x63lose\x18\x15 \x01(\x08\"%\n\x11ReplyTicketOutput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\"C\n\x10ListRepliesInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"F\n\x11ListRepliesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\"\n\x05items\x18\x02 \x03(\x0b\x32\x13.eolymp.judge.Reply\"7\n\x10\x44\x65leteReplyInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x10\n\x08reply_id\x18\x02 \x01(\t\"\x13\n\x11\x44\x65leteReplyOutput\"H\n\x10UpdateReplyInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x10\n\x08reply_id\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"\x13\n\x11UpdateReplyOutput\"<\n\x15\x43onfigureRuntimeInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0f\n\x07runtime\x18\x02 \x03(\t\"\x18\n\x16\x43onfigureRuntimeOutput\"*\n\x14\x44\x65scribeRuntimeInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"(\n\x15\x44\x65scribeRuntimeOutput\x12\x0f\n\x07runtime\x18\x01 \x03(\t\"[\n\x15\x43onfigureScoringInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12.\n\x07scoring\x18\x02 \x01(\x0b\x32\x1d.eolymp.judge.Contest.Scoring\"\x18\n\x16\x43onfigureScoringOutput\"*\n\x14\x44\x65scribeScoringInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"G\n\x15\x44\x65scribeScoringOutput\x12.\n\x07scoring\x18\x01 \x01(\x0b\x32\x1d.eolymp.judge.Contest.Scoring\"_\n\x17\x43reateAnnouncementInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x30\n\x0c\x61nnouncement\x18\x02 \x01(\x0b\x32\x1a.eolymp.judge.Announcement\"&\n\x18\x43reateAnnouncementOutput\x12\n\n\x02id\x18\x01 \x01(\t\"x\n\x17UpdateAnnouncementInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x17\n\x0f\x61nnouncement_id\x18\x02 \x01(\t\x12\x30\n\x0c\x61nnouncement\x18\x03 \x01(\x0b\x32\x1a.eolymp.judge.Announcement\"\x1a\n\x18UpdateAnnouncementOutput\"F\n\x17\x44\x65leteAnnouncementInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x17\n\x0f\x61nnouncement_id\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteAnnouncementOutput\"D\n\x15ReadAnnouncementInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x17\n\x0f\x61nnouncement_id\x18\x02 \x01(\t\"\x18\n\x16ReadAnnouncementOutput\"H\n\x19\x44\x65scribeAnnouncementInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x17\n\x0f\x61nnouncement_id\x18\x02 \x01(\t\"N\n\x1a\x44\x65scribeAnnouncementOutput\x12\x30\n\x0c\x61nnouncement\x18\x01 \x01(\x0b\x32\x1a.eolymp.judge.Announcement\"N\n\x1f\x44\x65scribeAnnouncementStatusInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x17\n\x0f\x61nnouncement_id\x18\x02 \x01(\t\"3\n DescribeAnnouncementStatusOutput\x12\x0f\n\x07is_read\x18\x01 \x01(\x08\"\xf1\x01\n\x16ListAnnouncementsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12<\n\x07\x66ilters\x18( \x01(\x0b\x32+.eolymp.judge.ListAnnouncementsInput.Filter\x1ag\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\x07is_read\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"S\n\x17ListAnnouncementsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12)\n\x05items\x18\x02 \x03(\x0b\x32\x1a.eolymp.judge.Announcement\"n\n\x19\x44\x65scribeCodeTemplateInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x13\n\x0btemplate_id\x18\x03 \x01(\t\x12\x14\n\x0ctemplate_ern\x18\x04 \x01(\t\"F\n\x1a\x44\x65scribeCodeTemplateOutput\x12(\n\x08template\x18\x01 \x01(\x0b\x32\x16.eolymp.judge.Template\"h\n\x17LookupCodeTemplateInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x14\n\x0bproblem_ern\x18\xe7\x07 \x01(\t\x12\x0f\n\x07runtime\x18\n \x01(\t\"D\n\x18LookupCodeTemplateOutput\x12(\n\x08template\x18\x01 \x01(\x0b\x32\x16.eolymp.judge.Template\"\'\n\x11RebuildScoreInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\")\n\x12RebuildScoreOutput\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\t\"*\n\x14IntrospectScoreInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\";\n\x15IntrospectScoreOutput\x12\"\n\x05score\x18\x01 \x01(\x0b\x32\x13.eolymp.judge.Score\"\x85\x01\n\x12\x44\x65scribeScoreInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12.\n\x04mode\x18\x03 \x01(\x0e\x32 .eolymp.judge.Score.FetchingMode\x12\x13\n\x0btime_offset\x18\x04 \x01(\x05\"9\n\x13\x44\x65scribeScoreOutput\x12\"\n\x05score\x18\x01 \x01(\x0b\x32\x13.eolymp.judge.Score\"c\n\x10ImportScoreInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12#\n\x06scores\x18\n \x03(\x0b\x32\x13.eolymp.judge.Score\"\x13\n\x11ImportScoreOutput\">\n\x10\x45xportScoreInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"8\n\x11\x45xportScoreOutput\x12#\n\x06scores\x18\n \x03(\x0b\x32\x13.eolymp.judge.Score\"\x88\x01\n\x0fListResultInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12.\n\x04mode\x18\x02 \x01(\x0e\x32 .eolymp.judge.Score.FetchingMode\x12\x13\n\x0btime_offset\x18\x03 \x01(\x05\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"F\n\x10ListResultOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.judge.Result\"G\n\x13ListActivitiesInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"L\n\x14ListActivitiesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.judge.Activity\"d\n\x18\x43onfigureAppearanceInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x34\n\nappearance\x18\x02 \x01(\x0b\x32 .eolymp.judge.Contest.Appearance\"\x1b\n\x19\x43onfigureAppearanceOutput\"-\n\x17\x44\x65scribeAppearanceInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"P\n\x18\x44\x65scribeAppearanceOutput\x12\x34\n\nappearance\x18\x01 \x01(\x0b\x32 .eolymp.judge.Contest.Appearance2\xeei\n\x05Judge\x12\x80\x01\n\rLookupContest\x12 .eolymp.judge.LookupContestInput\x1a!.eolymp.judge.LookupContestOutput\"*\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x14\x12\x12/contests/__lookup\x12\x91\x01\n\rCreateContest\x12 .eolymp.judge.CreateContestInput\x1a!.eolymp.judge.CreateContestOutput\";\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7\xa3=\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0b\"\t/contests\x12\x9e\x01\n\rDeleteContest\x12 .eolymp.judge.DeleteContestInput\x1a!.eolymp.judge.DeleteContestOutput\"H\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x18*\x16/contests/{contest_id}\x12\x9e\x01\n\rUpdateContest\x12 .eolymp.judge.UpdateContestInput\x1a!.eolymp.judge.UpdateContestOutput\"H\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x18\x1a\x16/contests/{contest_id}\x12\x89\x01\n\x0f\x44\x65scribeContest\x12\".eolymp.judge.DescribeContestInput\x1a#.eolymp.judge.DescribeContestOutput\"-\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x18\x12\x16/contests/{contest_id}\x12s\n\x0cListContests\x12\x1f.eolymp.judge.ListContestsInput\x1a .eolymp.judge.ListContestsOutput\" \xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x0b\x12\t/contests\x12\x9d\x01\n\x0bOpenContest\x12\x1e.eolymp.judge.OpenContestInput\x1a\x1f.eolymp.judge.OpenContestOutput\"M\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1d\"\x1b/contests/{contest_id}/open\x12\xa1\x01\n\x0c\x43loseContest\x12\x1f.eolymp.judge.CloseContestInput\x1a .eolymp.judge.CloseContestOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\"\x1c/contests/{contest_id}/close\x12\xa9\x01\n\x0eSuspendContest\x12!.eolymp.judge.SuspendContestInput\x1a\".eolymp.judge.SuspendContestOutput\"P\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02 \"\x1e/contests/{contest_id}/suspend\x12\xa5\x01\n\rFreezeContest\x12 .eolymp.judge.FreezeContestInput\x1a!.eolymp.judge.FreezeContestOutput\"O\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1f\"\x1d/contests/{contest_id}/freeze\x12\xa5\x01\n\rResumeContest\x12 .eolymp.judge.ResumeContestInput\x1a!.eolymp.judge.ResumeContestOutput\"O\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1f\"\x1d/contests/{contest_id}/resume\x12\xaf\x01\n\x10\x43onfigureRuntime\x12#.eolymp.judge.ConfigureRuntimeInput\x1a$.eolymp.judge.ConfigureRuntimeOutput\"P\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02 \"\x1e/contests/{contest_id}/runtime\x12\xab\x01\n\x0f\x44\x65scribeRuntime\x12\".eolymp.judge.DescribeRuntimeInput\x1a#.eolymp.judge.DescribeRuntimeOutput\"O\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02 \x12\x1e/contests/{contest_id}/runtime\x12\xbb\x01\n\x13\x43onfigureAppearance\x12&.eolymp.judge.ConfigureAppearanceInput\x1a\'.eolymp.judge.ConfigureAppearanceOutput\"S\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02#\"!/contests/{contest_id}/appearance\x12\xb7\x01\n\x12\x44\x65scribeAppearance\x12%.eolymp.judge.DescribeAppearanceInput\x1a&.eolymp.judge.DescribeAppearanceOutput\"R\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02#\x12!/contests/{contest_id}/appearance\x12\xaf\x01\n\x10\x43onfigureScoring\x12#.eolymp.judge.ConfigureScoringInput\x1a$.eolymp.judge.ConfigureScoringOutput\"P\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02 \"\x1e/contests/{contest_id}/scoring\x12\xab\x01\n\x0f\x44\x65scribeScoring\x12\".eolymp.judge.DescribeScoringInput\x1a#.eolymp.judge.DescribeScoringOutput\"O\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02 \x12\x1e/contests/{contest_id}/scoring\x12\xa7\x01\n\rImportProblem\x12 .eolymp.judge.ImportProblemInput\x1a!.eolymp.judge.ImportProblemOutput\"Q\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02!\"\x1f/contests/{contest_id}/problems\x12\xb3\x01\n\x0bSyncProblem\x12\x1e.eolymp.judge.SyncProblemInput\x1a\x1f.eolymp.judge.SyncProblemOutput\"c\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x33\"1/contests/{contest_id}/problems/{problem_id}/sync\x12\xb4\x01\n\rUpdateProblem\x12 .eolymp.judge.UpdateProblemInput\x1a!.eolymp.judge.UpdateProblemOutput\"^\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02.\",/contests/{contest_id}/problems/{problem_id}\x12\xa3\x01\n\x0cListProblems\x12\x1f.eolymp.judge.ListProblemsInput\x1a .eolymp.judge.ListProblemsOutput\"P\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00@@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02!\x12\x1f/contests/{contest_id}/problems\x12\xba\x01\n\x0f\x44\x65scribeProblem\x12\".eolymp.judge.DescribeProblemInput\x1a#.eolymp.judge.DescribeProblemOutput\"^\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02.\x12,/contests/{contest_id}/problems/{problem_id}\x12\xe0\x01\n\x14\x44\x65scribeCodeTemplate\x12\'.eolymp.judge.DescribeCodeTemplateInput\x1a(.eolymp.judge.DescribeCodeTemplateOutput\"u\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x46\x12\x44/contests/{contest_id}/problems/{problem_id}/templates/{template_id}\x12\xd2\x01\n\x12LookupCodeTemplate\x12%.eolymp.judge.LookupCodeTemplateInput\x1a&.eolymp.judge.LookupCodeTemplateOutput\"m\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02>\x12</contests/{contest_id}/problems/{problem_id}/lookup-template\x12\xc1\x01\n\x0eListStatements\x12!.eolymp.judge.ListStatementsInput\x1a\".eolymp.judge.ListStatementsOutput\"h\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x39\x12\x37/contests/{contest_id}/problems/{problem_id}/statements\x12\xc5\x01\n\x0fListAttachments\x12\".eolymp.judge.ListAttachmentsInput\x1a#.eolymp.judge.ListAttachmentsOutput\"i\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02:\x12\x38/contests/{contest_id}/problems/{problem_id}/attachments\x12\xb9\x01\n\x0cListExamples\x12\x1f.eolymp.judge.ListExamplesInput\x1a .eolymp.judge.ListExamplesOutput\"f\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x37\x12\x35/contests/{contest_id}/problems/{problem_id}/examples\x12\xb4\x01\n\rDeleteProblem\x12 .eolymp.judge.DeleteProblemInput\x1a!.eolymp.judge.DeleteProblemOutput\"^\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02.*,/contests/{contest_id}/problems/{problem_id}\x12\xbb\x01\n\rRetestProblem\x12 .eolymp.judge.RetestProblemInput\x1a!.eolymp.judge.RetestProblemOutput\"e\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x35\x12\x33/contests/{contest_id}/problems/{problem_id}/retest\x12\xae\x01\n\x0e\x41\x64\x64Participant\x12!.eolymp.judge.AddParticipantInput\x1a\".eolymp.judge.AddParticipantOutput\"U\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02%\"#/contests/{contest_id}/participants\x12\xcf\x01\n\x11\x45nableParticipant\x12$.eolymp.judge.EnableParticipantInput\x1a%.eolymp.judge.EnableParticipantOutput\"m\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02=\";/contests/{contest_id}/participants/{participant_id}/enable\x12\xd3\x01\n\x12\x44isableParticipant\x12%.eolymp.judge.DisableParticipantInput\x1a&.eolymp.judge.DisableParticipantOutput\"n\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02>\"</contests/{contest_id}/participants/{participant_id}/disable\x12\xc8\x01\n\x11UpdateParticipant\x12$.eolymp.judge.UpdateParticipantInput\x1a%.eolymp.judge.UpdateParticipantOutput\"f\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x36\x1a\x34/contests/{contest_id}/participants/{participant_id}\x12\xc8\x01\n\x11RemoveParticipant\x12$.eolymp.judge.RemoveParticipantInput\x1a%.eolymp.judge.RemoveParticipantOutput\"f\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x36*4/contests/{contest_id}/participants/{participant_id}\x12\xb3\x01\n\x10ListParticipants\x12#.eolymp.judge.ListParticipantsInput\x1a$.eolymp.judge.ListParticipantsOutput\"T\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02%\x12#/contests/{contest_id}/participants\x12\xce\x01\n\x13\x44\x65scribeParticipant\x12&.eolymp.judge.DescribeParticipantInput\x1a\'.eolymp.judge.DescribeParticipantOutput\"f\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x36\x12\x34/contests/{contest_id}/participants/{participant_id}\x12\xa6\x01\n\x15IntrospectParticipant\x12(.eolymp.judge.IntrospectParticipantInput\x1a).eolymp.judge.IntrospectParticipantOutput\"8\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02#\x12!/contests/{contest_id}/introspect\x12\x82\x01\n\x0bJoinContest\x12\x1e.eolymp.judge.JoinContestInput\x1a\x1f.eolymp.judge.JoinContestOutput\"2\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xd3\xe4\x93\x02\x1d\"\x1b/contests/{contest_id}/join\x12\xa7\x01\n\x0cStartContest\x12\x1f.eolymp.judge.StartContestInput\x1a .eolymp.judge.StartContestOutput\"T\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xd3\xe4\x93\x02\x1e\"\x1c/contests/{contest_id}/start\x12\xb0\x01\n\x0eVerifyPasscode\x12!.eolymp.judge.VerifyPasscodeInput\x1a\".eolymp.judge.VerifyPasscodeOutput\"W\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02(\"&/contests/{contest_id}/verify-passcode\x12\xb3\x01\n\rEnterPasscode\x12 .eolymp.judge.EnterPasscodeInput\x1a!.eolymp.judge.EnterPasscodeOutput\"]\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\'\"%/contests/{contest_id}/enter-passcode\x12\xc5\x01\n\rResetPasscode\x12 .eolymp.judge.ResetPasscodeInput\x1a!.eolymp.judge.ResetPasscodeOutput\"o\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02?\"=/contests/{contest_id}/participants/{participant_id}/passcode\x12\xbf\x01\n\x0bSetPasscode\x12\x1e.eolymp.judge.SetPasscodeInput\x1a\x1f.eolymp.judge.SetPasscodeOutput\"o\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02?\x1a=/contests/{contest_id}/participants/{participant_id}/passcode\x12\xc8\x01\n\x0eRemovePasscode\x12!.eolymp.judge.RemovePasscodeInput\x1a\".eolymp.judge.RemovePasscodeOutput\"o\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02?*=/contests/{contest_id}/participants/{participant_id}/passcode\x12\xcf\x01\n\x10\x43reateSubmission\x12#.eolymp.judge.CreateSubmissionInput\x1a$.eolymp.judge.CreateSubmissionOutput\"p\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\n\x82\xd3\xe4\x93\x02:\"8/contests/{contest_id}/problems/{problem_id}/submissions\x12\xaf\x01\n\x0fListSubmissions\x12\".eolymp.judge.ListSubmissionsInput\x1a#.eolymp.judge.ListSubmissionsOutput\"S\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02$\x12\"/contests/{contest_id}/submissions\x12\xc8\x01\n\x12\x44\x65scribeSubmission\x12%.eolymp.judge.DescribeSubmissionInput\x1a&.eolymp.judge.DescribeSubmissionOutput\"c\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x34\x12\x32/contests/{contest_id}/submissions/{submission_id}\x12\xca\x01\n\x10RetestSubmission\x12#.eolymp.judge.RetestSubmissionInput\x1a$.eolymp.judge.RetestSubmissionOutput\"k\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02;\"9/contests/{contest_id}/submissions/{submission_id}/retest\x12\xc3\x01\n\x10\x44\x65leteSubmission\x12#.eolymp.judge.DeleteSubmissionInput\x1a$.eolymp.judge.DeleteSubmissionOutput\"d\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x34*2/contests/{contest_id}/submissions/{submission_id}\x12\xce\x01\n\x11RestoreSubmission\x12$.eolymp.judge.RestoreSubmissionInput\x1a%.eolymp.judge.RestoreSubmissionOutput\"l\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02<\":/contests/{contest_id}/submissions/{submission_id}/restore\x12\xa9\x01\n\x0c\x43reateTicket\x12\x1f.eolymp.judge.CreateTicketInput\x1a .eolymp.judge.CreateTicketOutput\"V\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02 \"\x1e/contests/{contest_id}/tickets\x12\x9c\x01\n\x0b\x43loseTicket\x12\x1e.eolymp.judge.CloseTicketInput\x1a\x1f.eolymp.judge.CloseTicketOutput\"L\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1c\"\x1a/tickets/{ticket_id}/close\x12\x98\x01\n\nOpenTicket\x12\x1d.eolymp.judge.OpenTicketInput\x1a\x1e.eolymp.judge.OpenTicketOutput\"K\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1b\"\x19/tickets/{ticket_id}/open\x12\x97\x01\n\nReadTicket\x12\x1d.eolymp.judge.ReadTicketInput\x1a\x1e.eolymp.judge.ReadTicketOutput\"J\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1b\"\x19/tickets/{ticket_id}/read\x12\x99\x01\n\x0c\x44\x65leteTicket\x12\x1f.eolymp.judge.DeleteTicketInput\x1a .eolymp.judge.DeleteTicketOutput\"F\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x16*\x14/tickets/{ticket_id}\x12\x9e\x01\n\x0e\x44\x65scribeTicket\x12!.eolymp.judge.DescribeTicketInput\x1a\".eolymp.judge.DescribeTicketOutput\"E\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x16\x12\x14/tickets/{ticket_id}\x12\x89\x01\n\x0bListTickets\x12\x1e.eolymp.judge.ListTicketsInput\x1a\x1f.eolymp.judge.ListTicketsOutput\"9\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\n\x12\x08/tickets\x12\xa4\x01\n\x0bReplyTicket\x12\x1e.eolymp.judge.ReplyTicketInput\x1a\x1f.eolymp.judge.ReplyTicketOutput\"T\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\"\x1c/tickets/{ticket_id}/replies\x12\x9d\x01\n\x0bListReplies\x12\x1e.eolymp.judge.ListRepliesInput\x1a\x1f.eolymp.judge.ListRepliesOutput\"M\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1e\x12\x1c/tickets/{ticket_id}/replies\x12\xa9\x01\n\x0b\x44\x65leteReply\x12\x1e.eolymp.judge.DeleteReplyInput\x1a\x1f.eolymp.judge.DeleteReplyOutput\"Y\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02)*\'/tickets/{ticket_id}/replies/{reply_id}\x12\xa9\x01\n\x0bUpdateReply\x12\x1e.eolymp.judge.UpdateReplyInput\x1a\x1f.eolymp.judge.UpdateReplyOutput\"Y\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02)\"\'/tickets/{ticket_id}/replies/{reply_id}\x12\xbb\x01\n\x12\x43reateAnnouncement\x12%.eolymp.judge.CreateAnnouncementInput\x1a&.eolymp.judge.CreateAnnouncementOutput\"V\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02&\"$/contests/{contest_id}/announcements\x12\xcd\x01\n\x12UpdateAnnouncement\x12%.eolymp.judge.UpdateAnnouncementInput\x1a&.eolymp.judge.UpdateAnnouncementOutput\"h\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x38\"6/contests/{contest_id}/announcements/{announcement_id}\x12\xcd\x01\n\x12\x44\x65leteAnnouncement\x12%.eolymp.judge.DeleteAnnouncementInput\x1a&.eolymp.judge.DeleteAnnouncementOutput\"h\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x38*6/contests/{contest_id}/announcements/{announcement_id}\x12\xcb\x01\n\x10ReadAnnouncement\x12#.eolymp.judge.ReadAnnouncementInput\x1a$.eolymp.judge.ReadAnnouncementOutput\"l\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02=\";/contests/{contest_id}/announcements/{announcement_id}/read\x12\xd2\x01\n\x14\x44\x65scribeAnnouncement\x12\'.eolymp.judge.DescribeAnnouncementInput\x1a(.eolymp.judge.DescribeAnnouncementOutput\"g\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x38\x12\x36/contests/{contest_id}/announcements/{announcement_id}\x12\xeb\x01\n\x1a\x44\x65scribeAnnouncementStatus\x12-.eolymp.judge.DescribeAnnouncementStatusInput\x1a..eolymp.judge.DescribeAnnouncementStatusOutput\"n\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02?\x12=/contests/{contest_id}/announcements/{announcement_id}/status\x12\xb7\x01\n\x11ListAnnouncements\x12$.eolymp.judge.ListAnnouncementsInput\x1a%.eolymp.judge.ListAnnouncementsOutput\"U\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02&\x12$/contests/{contest_id}/announcements\x12\x9a\x01\n\x0fIntrospectScore\x12\".eolymp.judge.IntrospectScoreInput\x1a#.eolymp.judge.IntrospectScoreOutput\">\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02)\x12\'/contests/{contest_id}/introspect/score\x12\xc2\x01\n\rDescribeScore\x12 .eolymp.judge.DescribeScoreInput\x1a!.eolymp.judge.DescribeScoreOutput\"l\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02<\x12:/contests/{contest_id}/participants/{participant_id}/score\x12\xbd\x01\n\x0bImportScore\x12\x1e.eolymp.judge.ImportScoreInput\x1a\x1f.eolymp.judge.ImportScoreOutput\"m\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02=\";/contests/{contest_id}/participants/{participant_id}/scores\x12\xbd\x01\n\x0b\x45xportScore\x12\x1e.eolymp.judge.ExportScoreInput\x1a\x1f.eolymp.judge.ExportScoreOutput\"m\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02=\x12;/contests/{contest_id}/participants/{participant_id}/scores\x12\x9d\x01\n\nListResult\x12\x1d.eolymp.judge.ListResultInput\x1a\x1e.eolymp.judge.ListResultOutput\"P\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02 \x12\x1e/contests/{contest_id}/results\x12\xa3\x01\n\x0cRebuildScore\x12\x1f.eolymp.judge.RebuildScoreInput\x1a .eolymp.judge.RebuildScoreOutput\"P\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02 \"\x1e/contests/{contest_id}/rebuild\x12\xab\x01\n\x0eListActivities\x12!.eolymp.judge.ListActivitiesInput\x1a\".eolymp.judge.ListActivitiesOutput\"R\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02#\x12!/contests/{contest_id}/activitiesB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.judge_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _JUDGE.methods_by_name['LookupContest']._options = None
  _JUDGE.methods_by_name['LookupContest']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\323\344\223\002\024\022\022/contests/__lookup'
  _JUDGE.methods_by_name['CreateContest']._options = None
  _JUDGE.methods_by_name['CreateContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\n\327\243=\370\342\n\005\202\323\344\223\002\013\"\t/contests'
  _JUDGE.methods_by_name['DeleteContest']._options = None
  _JUDGE.methods_by_name['DeleteContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\030*\026/contests/{contest_id}'
  _JUDGE.methods_by_name['UpdateContest']._options = None
  _JUDGE.methods_by_name['UpdateContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\030\032\026/contests/{contest_id}'
  _JUDGE.methods_by_name['DescribeContest']._options = None
  _JUDGE.methods_by_name['DescribeContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\030\022\026/contests/{contest_id}'
  _JUDGE.methods_by_name['ListContests']._options = None
  _JUDGE.methods_by_name['ListContests']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\013\022\t/contests'
  _JUDGE.methods_by_name['OpenContest']._options = None
  _JUDGE.methods_by_name['OpenContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\035\"\033/contests/{contest_id}/open'
  _JUDGE.methods_by_name['CloseContest']._options = None
  _JUDGE.methods_by_name['CloseContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036\"\034/contests/{contest_id}/close'
  _JUDGE.methods_by_name['SuspendContest']._options = None
  _JUDGE.methods_by_name['SuspendContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002 \"\036/contests/{contest_id}/suspend'
  _JUDGE.methods_by_name['FreezeContest']._options = None
  _JUDGE.methods_by_name['FreezeContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\037\"\035/contests/{contest_id}/freeze'
  _JUDGE.methods_by_name['ResumeContest']._options = None
  _JUDGE.methods_by_name['ResumeContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\037\"\035/contests/{contest_id}/resume'
  _JUDGE.methods_by_name['ConfigureRuntime']._options = None
  _JUDGE.methods_by_name['ConfigureRuntime']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002 \"\036/contests/{contest_id}/runtime'
  _JUDGE.methods_by_name['DescribeRuntime']._options = None
  _JUDGE.methods_by_name['DescribeRuntime']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002 \022\036/contests/{contest_id}/runtime'
  _JUDGE.methods_by_name['ConfigureAppearance']._options = None
  _JUDGE.methods_by_name['ConfigureAppearance']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002#\"!/contests/{contest_id}/appearance'
  _JUDGE.methods_by_name['DescribeAppearance']._options = None
  _JUDGE.methods_by_name['DescribeAppearance']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002#\022!/contests/{contest_id}/appearance'
  _JUDGE.methods_by_name['ConfigureScoring']._options = None
  _JUDGE.methods_by_name['ConfigureScoring']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002 \"\036/contests/{contest_id}/scoring'
  _JUDGE.methods_by_name['DescribeScoring']._options = None
  _JUDGE.methods_by_name['DescribeScoring']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002 \022\036/contests/{contest_id}/scoring'
  _JUDGE.methods_by_name['ImportProblem']._options = None
  _JUDGE.methods_by_name['ImportProblem']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002!\"\037/contests/{contest_id}/problems'
  _JUDGE.methods_by_name['SyncProblem']._options = None
  _JUDGE.methods_by_name['SyncProblem']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\0023\"1/contests/{contest_id}/problems/{problem_id}/sync'
  _JUDGE.methods_by_name['UpdateProblem']._options = None
  _JUDGE.methods_by_name['UpdateProblem']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002.\",/contests/{contest_id}/problems/{problem_id}'
  _JUDGE.methods_by_name['ListProblems']._options = None
  _JUDGE.methods_by_name['ListProblems']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000@@\370\342\n\n\202\323\344\223\002!\022\037/contests/{contest_id}/problems'
  _JUDGE.methods_by_name['DescribeProblem']._options = None
  _JUDGE.methods_by_name['DescribeProblem']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\323\344\223\002.\022,/contests/{contest_id}/problems/{problem_id}'
  _JUDGE.methods_by_name['DescribeCodeTemplate']._options = None
  _JUDGE.methods_by_name['DescribeCodeTemplate']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002F\022D/contests/{contest_id}/problems/{problem_id}/templates/{template_id}'
  _JUDGE.methods_by_name['LookupCodeTemplate']._options = None
  _JUDGE.methods_by_name['LookupCodeTemplate']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002>\022</contests/{contest_id}/problems/{problem_id}/lookup-template'
  _JUDGE.methods_by_name['ListStatements']._options = None
  _JUDGE.methods_by_name['ListStatements']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\0029\0227/contests/{contest_id}/problems/{problem_id}/statements'
  _JUDGE.methods_by_name['ListAttachments']._options = None
  _JUDGE.methods_by_name['ListAttachments']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002:\0228/contests/{contest_id}/problems/{problem_id}/attachments'
  _JUDGE.methods_by_name['ListExamples']._options = None
  _JUDGE.methods_by_name['ListExamples']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\0027\0225/contests/{contest_id}/problems/{problem_id}/examples'
  _JUDGE.methods_by_name['DeleteProblem']._options = None
  _JUDGE.methods_by_name['DeleteProblem']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002.*,/contests/{contest_id}/problems/{problem_id}'
  _JUDGE.methods_by_name['RetestProblem']._options = None
  _JUDGE.methods_by_name['RetestProblem']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\0025\0223/contests/{contest_id}/problems/{problem_id}/retest'
  _JUDGE.methods_by_name['AddParticipant']._options = None
  _JUDGE.methods_by_name['AddParticipant']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002%\"#/contests/{contest_id}/participants'
  _JUDGE.methods_by_name['EnableParticipant']._options = None
  _JUDGE.methods_by_name['EnableParticipant']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002=\";/contests/{contest_id}/participants/{participant_id}/enable'
  _JUDGE.methods_by_name['DisableParticipant']._options = None
  _JUDGE.methods_by_name['DisableParticipant']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002>\"</contests/{contest_id}/participants/{participant_id}/disable'
  _JUDGE.methods_by_name['UpdateParticipant']._options = None
  _JUDGE.methods_by_name['UpdateParticipant']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\0026\0324/contests/{contest_id}/participants/{participant_id}'
  _JUDGE.methods_by_name['RemoveParticipant']._options = None
  _JUDGE.methods_by_name['RemoveParticipant']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\0026*4/contests/{contest_id}/participants/{participant_id}'
  _JUDGE.methods_by_name['ListParticipants']._options = None
  _JUDGE.methods_by_name['ListParticipants']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002%\022#/contests/{contest_id}/participants'
  _JUDGE.methods_by_name['DescribeParticipant']._options = None
  _JUDGE.methods_by_name['DescribeParticipant']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\323\344\223\0026\0224/contests/{contest_id}/participants/{participant_id}'
  _JUDGE.methods_by_name['IntrospectParticipant']._options = None
  _JUDGE.methods_by_name['IntrospectParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002#\022!/contests/{contest_id}/introspect'
  _JUDGE.methods_by_name['JoinContest']._options = None
  _JUDGE.methods_by_name['JoinContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\323\344\223\002\035\"\033/contests/{contest_id}/join'
  _JUDGE.methods_by_name['StartContest']._options = None
  _JUDGE.methods_by_name['StartContest']._serialized_options = b'\202\343\n\035\212\343\n\031judge:contest:participate\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\323\344\223\002\036\"\034/contests/{contest_id}/start'
  _JUDGE.methods_by_name['VerifyPasscode']._options = None
  _JUDGE.methods_by_name['VerifyPasscode']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002(\"&/contests/{contest_id}/verify-passcode'
  _JUDGE.methods_by_name['EnterPasscode']._options = None
  _JUDGE.methods_by_name['EnterPasscode']._serialized_options = b'\202\343\n\035\212\343\n\031judge:contest:participate\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\'\"%/contests/{contest_id}/enter-passcode'
  _JUDGE.methods_by_name['ResetPasscode']._options = None
  _JUDGE.methods_by_name['ResetPasscode']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002?\"=/contests/{contest_id}/participants/{participant_id}/passcode'
  _JUDGE.methods_by_name['SetPasscode']._options = None
  _JUDGE.methods_by_name['SetPasscode']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002?\032=/contests/{contest_id}/participants/{participant_id}/passcode'
  _JUDGE.methods_by_name['RemovePasscode']._options = None
  _JUDGE.methods_by_name['RemovePasscode']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002?*=/contests/{contest_id}/participants/{participant_id}/passcode'
  _JUDGE.methods_by_name['CreateSubmission']._options = None
  _JUDGE.methods_by_name['CreateSubmission']._serialized_options = b'\202\343\n\035\212\343\n\031judge:contest:participate\352\342\n\013\365\342\n\n\327#>\370\342\n\n\202\323\344\223\002:\"8/contests/{contest_id}/problems/{problem_id}/submissions'
  _JUDGE.methods_by_name['ListSubmissions']._options = None
  _JUDGE.methods_by_name['ListSubmissions']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002$\022\"/contests/{contest_id}/submissions'
  _JUDGE.methods_by_name['DescribeSubmission']._options = None
  _JUDGE.methods_by_name['DescribeSubmission']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\0024\0222/contests/{contest_id}/submissions/{submission_id}'
  _JUDGE.methods_by_name['RetestSubmission']._options = None
  _JUDGE.methods_by_name['RetestSubmission']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002;\"9/contests/{contest_id}/submissions/{submission_id}/retest'
  _JUDGE.methods_by_name['DeleteSubmission']._options = None
  _JUDGE.methods_by_name['DeleteSubmission']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\0024*2/contests/{contest_id}/submissions/{submission_id}'
  _JUDGE.methods_by_name['RestoreSubmission']._options = None
  _JUDGE.methods_by_name['RestoreSubmission']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002<\":/contests/{contest_id}/submissions/{submission_id}/restore'
  _JUDGE.methods_by_name['CreateTicket']._options = None
  _JUDGE.methods_by_name['CreateTicket']._serialized_options = b'\202\343\n\035\212\343\n\031judge:contest:participate\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002 \"\036/contests/{contest_id}/tickets'
  _JUDGE.methods_by_name['CloseTicket']._options = None
  _JUDGE.methods_by_name['CloseTicket']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\034\"\032/tickets/{ticket_id}/close'
  _JUDGE.methods_by_name['OpenTicket']._options = None
  _JUDGE.methods_by_name['OpenTicket']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\033\"\031/tickets/{ticket_id}/open'
  _JUDGE.methods_by_name['ReadTicket']._options = None
  _JUDGE.methods_by_name['ReadTicket']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\033\"\031/tickets/{ticket_id}/read'
  _JUDGE.methods_by_name['DeleteTicket']._options = None
  _JUDGE.methods_by_name['DeleteTicket']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\026*\024/tickets/{ticket_id}'
  _JUDGE.methods_by_name['DescribeTicket']._options = None
  _JUDGE.methods_by_name['DescribeTicket']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\026\022\024/tickets/{ticket_id}'
  _JUDGE.methods_by_name['ListTickets']._options = None
  _JUDGE.methods_by_name['ListTickets']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\n\022\010/tickets'
  _JUDGE.methods_by_name['ReplyTicket']._options = None
  _JUDGE.methods_by_name['ReplyTicket']._serialized_options = b'\202\343\n\035\212\343\n\031judge:contest:participate\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\036\"\034/tickets/{ticket_id}/replies'
  _JUDGE.methods_by_name['ListReplies']._options = None
  _JUDGE.methods_by_name['ListReplies']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\036\022\034/tickets/{ticket_id}/replies'
  _JUDGE.methods_by_name['DeleteReply']._options = None
  _JUDGE.methods_by_name['DeleteReply']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002)*\'/tickets/{ticket_id}/replies/{reply_id}'
  _JUDGE.methods_by_name['UpdateReply']._options = None
  _JUDGE.methods_by_name['UpdateReply']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002)\"\'/tickets/{ticket_id}/replies/{reply_id}'
  _JUDGE.methods_by_name['CreateAnnouncement']._options = None
  _JUDGE.methods_by_name['CreateAnnouncement']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002&\"$/contests/{contest_id}/announcements'
  _JUDGE.methods_by_name['UpdateAnnouncement']._options = None
  _JUDGE.methods_by_name['UpdateAnnouncement']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\0028\"6/contests/{contest_id}/announcements/{announcement_id}'
  _JUDGE.methods_by_name['DeleteAnnouncement']._options = None
  _JUDGE.methods_by_name['DeleteAnnouncement']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\0028*6/contests/{contest_id}/announcements/{announcement_id}'
  _JUDGE.methods_by_name['ReadAnnouncement']._options = None
  _JUDGE.methods_by_name['ReadAnnouncement']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002=\";/contests/{contest_id}/announcements/{announcement_id}/read'
  _JUDGE.methods_by_name['DescribeAnnouncement']._options = None
  _JUDGE.methods_by_name['DescribeAnnouncement']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\0028\0226/contests/{contest_id}/announcements/{announcement_id}'
  _JUDGE.methods_by_name['DescribeAnnouncementStatus']._options = None
  _JUDGE.methods_by_name['DescribeAnnouncementStatus']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002?\022=/contests/{contest_id}/announcements/{announcement_id}/status'
  _JUDGE.methods_by_name['ListAnnouncements']._options = None
  _JUDGE.methods_by_name['ListAnnouncements']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002&\022$/contests/{contest_id}/announcements'
  _JUDGE.methods_by_name['IntrospectScore']._options = None
  _JUDGE.methods_by_name['IntrospectScore']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002)\022\'/contests/{contest_id}/introspect/score'
  _JUDGE.methods_by_name['DescribeScore']._options = None
  _JUDGE.methods_by_name['DescribeScore']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\323\344\223\002<\022:/contests/{contest_id}/participants/{participant_id}/score'
  _JUDGE.methods_by_name['ImportScore']._options = None
  _JUDGE.methods_by_name['ImportScore']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\323\344\223\002=\";/contests/{contest_id}/participants/{participant_id}/scores'
  _JUDGE.methods_by_name['ExportScore']._options = None
  _JUDGE.methods_by_name['ExportScore']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\323\344\223\002=\022;/contests/{contest_id}/participants/{participant_id}/scores'
  _JUDGE.methods_by_name['ListResult']._options = None
  _JUDGE.methods_by_name['ListResult']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\323\344\223\002 \022\036/contests/{contest_id}/results'
  _JUDGE.methods_by_name['RebuildScore']._options = None
  _JUDGE.methods_by_name['RebuildScore']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002 \"\036/contests/{contest_id}/rebuild'
  _JUDGE.methods_by_name['ListActivities']._options = None
  _JUDGE.methods_by_name['ListActivities']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002#\022!/contests/{contest_id}/activities'
  _CREATECONTESTINPUT._serialized_start=526
  _CREATECONTESTINPUT._serialized_end=586
  _CREATECONTESTOUTPUT._serialized_start=588
  _CREATECONTESTOUTPUT._serialized_end=629
  _DELETECONTESTINPUT._serialized_start=631
  _DELETECONTESTINPUT._serialized_end=671
  _DELETECONTESTOUTPUT._serialized_start=673
  _DELETECONTESTOUTPUT._serialized_end=694
  _UPDATECONTESTINPUT._serialized_start=696
  _UPDATECONTESTINPUT._serialized_end=776
  _UPDATECONTESTOUTPUT._serialized_start=778
  _UPDATECONTESTOUTPUT._serialized_end=799
  _DESCRIBECONTESTINPUT._serialized_start=801
  _DESCRIBECONTESTINPUT._serialized_end=843
  _DESCRIBECONTESTOUTPUT._serialized_start=845
  _DESCRIBECONTESTOUTPUT._serialized_end=908
  _LOOKUPCONTESTINPUT._serialized_start=910
  _LOOKUPCONTESTINPUT._serialized_end=943
  _LOOKUPCONTESTOUTPUT._serialized_start=945
  _LOOKUPCONTESTOUTPUT._serialized_end=1060
  _LISTCONTESTSINPUT._serialized_start=1063
  _LISTCONTESTSINPUT._serialized_end=1589
  _LISTCONTESTSINPUT_FILTER._serialized_start=1172
  _LISTCONTESTSINPUT_FILTER._serialized_end=1589
  _LISTCONTESTSOUTPUT._serialized_start=1591
  _LISTCONTESTSOUTPUT._serialized_end=1664
  _OPENCONTESTINPUT._serialized_start=1666
  _OPENCONTESTINPUT._serialized_end=1704
  _OPENCONTESTOUTPUT._serialized_start=1706
  _OPENCONTESTOUTPUT._serialized_end=1725
  _CLOSECONTESTINPUT._serialized_start=1727
  _CLOSECONTESTINPUT._serialized_end=1766
  _CLOSECONTESTOUTPUT._serialized_start=1768
  _CLOSECONTESTOUTPUT._serialized_end=1788
  _SUSPENDCONTESTINPUT._serialized_start=1790
  _SUSPENDCONTESTINPUT._serialized_end=1831
  _SUSPENDCONTESTOUTPUT._serialized_start=1833
  _SUSPENDCONTESTOUTPUT._serialized_end=1855
  _FREEZECONTESTINPUT._serialized_start=1857
  _FREEZECONTESTINPUT._serialized_end=1897
  _FREEZECONTESTOUTPUT._serialized_start=1899
  _FREEZECONTESTOUTPUT._serialized_end=1920
  _RESUMECONTESTINPUT._serialized_start=1922
  _RESUMECONTESTINPUT._serialized_end=1962
  _RESUMECONTESTOUTPUT._serialized_start=1964
  _RESUMECONTESTOUTPUT._serialized_end=1985
  _JOINCONTESTINPUT._serialized_start=1987
  _JOINCONTESTINPUT._serialized_end=2025
  _JOINCONTESTOUTPUT._serialized_start=2027
  _JOINCONTESTOUTPUT._serialized_end=2046
  _STARTCONTESTINPUT._serialized_start=2048
  _STARTCONTESTINPUT._serialized_end=2087
  _STARTCONTESTOUTPUT._serialized_start=2089
  _STARTCONTESTOUTPUT._serialized_end=2109
  _IMPORTPROBLEMINPUT._serialized_start=2111
  _IMPORTPROBLEMINPUT._serialized_end=2238
  _IMPORTPROBLEMOUTPUT._serialized_start=2240
  _IMPORTPROBLEMOUTPUT._serialized_end=2281
  _SYNCPROBLEMINPUT._serialized_start=2283
  _SYNCPROBLEMINPUT._serialized_end=2341
  _SYNCPROBLEMOUTPUT._serialized_start=2343
  _SYNCPROBLEMOUTPUT._serialized_end=2362
  _UPDATEPROBLEMINPUT._serialized_start=2365
  _UPDATEPROBLEMINPUT._serialized_end=2493
  _UPDATEPROBLEMOUTPUT._serialized_start=2495
  _UPDATEPROBLEMOUTPUT._serialized_end=2516
  _DELETEPROBLEMINPUT._serialized_start=2518
  _DELETEPROBLEMINPUT._serialized_end=2578
  _DELETEPROBLEMOUTPUT._serialized_start=2580
  _DELETEPROBLEMOUTPUT._serialized_end=2601
  _RETESTPROBLEMINPUT._serialized_start=2603
  _RETESTPROBLEMINPUT._serialized_end=2663
  _RETESTPROBLEMOUTPUT._serialized_start=2665
  _RETESTPROBLEMOUTPUT._serialized_end=2686
  _LISTPROBLEMSINPUT._serialized_start=2688
  _LISTPROBLEMSINPUT._serialized_end=2757
  _LISTPROBLEMSOUTPUT._serialized_start=2759
  _LISTPROBLEMSOUTPUT._serialized_end=2832
  _DESCRIBEPROBLEMINPUT._serialized_start=2834
  _DESCRIBEPROBLEMINPUT._serialized_end=2918
  _DESCRIBEPROBLEMOUTPUT._serialized_start=2920
  _DESCRIBEPROBLEMOUTPUT._serialized_end=2983
  _LISTSTATEMENTSINPUT._serialized_start=2985
  _LISTSTATEMENTSINPUT._serialized_end=3046
  _LISTSTATEMENTSOUTPUT._serialized_start=3048
  _LISTSTATEMENTSOUTPUT._serialized_end=3133
  _LISTATTACHMENTSINPUT._serialized_start=3135
  _LISTATTACHMENTSINPUT._serialized_end=3197
  _LISTATTACHMENTSOUTPUT._serialized_start=3199
  _LISTATTACHMENTSOUTPUT._serialized_end=3286
  _LISTEXAMPLESINPUT._serialized_start=3288
  _LISTEXAMPLESINPUT._serialized_end=3347
  _LISTEXAMPLESOUTPUT._serialized_start=3349
  _LISTEXAMPLESOUTPUT._serialized_end=3427
  _ADDPARTICIPANTINPUT._serialized_start=3429
  _ADDPARTICIPANTINPUT._serialized_end=3531
  _ADDPARTICIPANTOUTPUT._serialized_start=3533
  _ADDPARTICIPANTOUTPUT._serialized_end=3579
  _ENABLEPARTICIPANTINPUT._serialized_start=3581
  _ENABLEPARTICIPANTINPUT._serialized_end=3649
  _ENABLEPARTICIPANTOUTPUT._serialized_start=3651
  _ENABLEPARTICIPANTOUTPUT._serialized_end=3676
  _DISABLEPARTICIPANTINPUT._serialized_start=3678
  _DISABLEPARTICIPANTINPUT._serialized_end=3747
  _DISABLEPARTICIPANTOUTPUT._serialized_start=3749
  _DISABLEPARTICIPANTOUTPUT._serialized_end=3775
  _UPDATEPARTICIPANTINPUT._serialized_start=3778
  _UPDATEPARTICIPANTINPUT._serialized_end=4035
  _UPDATEPARTICIPANTINPUT_PATCH._serialized_start=3969
  _UPDATEPARTICIPANTINPUT_PATCH._serialized_end=4035
  _UPDATEPARTICIPANTOUTPUT._serialized_start=4037
  _UPDATEPARTICIPANTOUTPUT._serialized_end=4062
  _REMOVEPARTICIPANTINPUT._serialized_start=4064
  _REMOVEPARTICIPANTINPUT._serialized_end=4132
  _REMOVEPARTICIPANTOUTPUT._serialized_start=4134
  _REMOVEPARTICIPANTOUTPUT._serialized_end=4159
  _VERIFYPASSCODEINPUT._serialized_start=4161
  _VERIFYPASSCODEINPUT._serialized_end=4202
  _VERIFYPASSCODEOUTPUT._serialized_start=4204
  _VERIFYPASSCODEOUTPUT._serialized_end=4259
  _ENTERPASSCODEINPUT._serialized_start=4261
  _ENTERPASSCODEINPUT._serialized_end=4319
  _ENTERPASSCODEOUTPUT._serialized_start=4321
  _ENTERPASSCODEOUTPUT._serialized_end=4342
  _RESETPASSCODEINPUT._serialized_start=4344
  _RESETPASSCODEINPUT._serialized_end=4408
  _RESETPASSCODEOUTPUT._serialized_start=4410
  _RESETPASSCODEOUTPUT._serialized_end=4449
  _SETPASSCODEINPUT._serialized_start=4451
  _SETPASSCODEINPUT._serialized_end=4531
  _SETPASSCODEOUTPUT._serialized_start=4533
  _SETPASSCODEOUTPUT._serialized_end=4552
  _REMOVEPASSCODEINPUT._serialized_start=4554
  _REMOVEPASSCODEINPUT._serialized_end=4619
  _REMOVEPASSCODEOUTPUT._serialized_start=4621
  _REMOVEPASSCODEOUTPUT._serialized_end=4643
  _LISTPARTICIPANTSINPUT._serialized_start=4646
  _LISTPARTICIPANTSINPUT._serialized_end=5390
  _LISTPARTICIPANTSINPUT_FILTER._serialized_start=4887
  _LISTPARTICIPANTSINPUT_FILTER._serialized_end=5311
  _LISTPARTICIPANTSINPUT_SORTABLE._serialized_start=5313
  _LISTPARTICIPANTSINPUT_SORTABLE._serialized_end=5390
  _LISTPARTICIPANTSOUTPUT._serialized_start=5392
  _LISTPARTICIPANTSOUTPUT._serialized_end=5473
  _INTROSPECTPARTICIPANTINPUT._serialized_start=5475
  _INTROSPECTPARTICIPANTINPUT._serialized_end=5523
  _INTROSPECTPARTICIPANTOUTPUT._serialized_start=5525
  _INTROSPECTPARTICIPANTOUTPUT._serialized_end=5602
  _DESCRIBEPARTICIPANTINPUT._serialized_start=5604
  _DESCRIBEPARTICIPANTINPUT._serialized_end=5674
  _DESCRIBEPARTICIPANTOUTPUT._serialized_start=5676
  _DESCRIBEPARTICIPANTOUTPUT._serialized_end=5751
  _CREATESUBMISSIONINPUT._serialized_start=5753
  _CREATESUBMISSIONINPUT._serialized_end=5846
  _CREATESUBMISSIONOUTPUT._serialized_start=5848
  _CREATESUBMISSIONOUTPUT._serialized_end=5895
  _LISTSUBMISSIONSINPUT._serialized_start=5898
  _LISTSUBMISSIONSINPUT._serialized_end=6510
  _LISTSUBMISSIONSINPUT_FILTER._serialized_start=6033
  _LISTSUBMISSIONSINPUT_FILTER._serialized_end=6510
  _LISTSUBMISSIONSOUTPUT._serialized_start=6512
  _LISTSUBMISSIONSOUTPUT._serialized_end=6591
  _DESCRIBESUBMISSIONINPUT._serialized_start=6593
  _DESCRIBESUBMISSIONINPUT._serialized_end=6661
  _DESCRIBESUBMISSIONOUTPUT._serialized_start=6663
  _DESCRIBESUBMISSIONOUTPUT._serialized_end=6735
  _RETESTSUBMISSIONINPUT._serialized_start=6737
  _RETESTSUBMISSIONINPUT._serialized_end=6803
  _RETESTSUBMISSIONOUTPUT._serialized_start=6805
  _RETESTSUBMISSIONOUTPUT._serialized_end=6829
  _DELETESUBMISSIONINPUT._serialized_start=6831
  _DELETESUBMISSIONINPUT._serialized_end=6897
  _DELETESUBMISSIONOUTPUT._serialized_start=6899
  _DELETESUBMISSIONOUTPUT._serialized_end=6923
  _RESTORESUBMISSIONINPUT._serialized_start=6925
  _RESTORESUBMISSIONINPUT._serialized_end=6992
  _RESTORESUBMISSIONOUTPUT._serialized_start=6994
  _RESTORESUBMISSIONOUTPUT._serialized_end=7019
  _CREATETICKETINPUT._serialized_start=7021
  _CREATETICKETINPUT._serialized_end=7094
  _CREATETICKETOUTPUT._serialized_start=7096
  _CREATETICKETOUTPUT._serialized_end=7135
  _CLOSETICKETINPUT._serialized_start=7137
  _CLOSETICKETINPUT._serialized_end=7194
  _CLOSETICKETOUTPUT._serialized_start=7196
  _CLOSETICKETOUTPUT._serialized_end=7215
  _OPENTICKETINPUT._serialized_start=7217
  _OPENTICKETINPUT._serialized_end=7273
  _OPENTICKETOUTPUT._serialized_start=7275
  _OPENTICKETOUTPUT._serialized_end=7293
  _READTICKETINPUT._serialized_start=7295
  _READTICKETINPUT._serialized_end=7351
  _READTICKETOUTPUT._serialized_start=7353
  _READTICKETOUTPUT._serialized_end=7371
  _DELETETICKETINPUT._serialized_start=7373
  _DELETETICKETINPUT._serialized_end=7431
  _DELETETICKETOUTPUT._serialized_start=7433
  _DELETETICKETOUTPUT._serialized_end=7453
  _DESCRIBETICKETINPUT._serialized_start=7455
  _DESCRIBETICKETINPUT._serialized_end=7515
  _DESCRIBETICKETOUTPUT._serialized_start=7517
  _DESCRIBETICKETOUTPUT._serialized_end=7577
  _LISTTICKETSINPUT._serialized_start=7580
  _LISTTICKETSINPUT._serialized_end=8242
  _LISTTICKETSINPUT_FILTER._serialized_start=7786
  _LISTTICKETSINPUT_FILTER._serialized_end=8170
  _LISTTICKETSINPUT_SORTABLE._serialized_start=8172
  _LISTTICKETSINPUT_SORTABLE._serialized_end=8242
  _LISTTICKETSOUTPUT._serialized_start=8244
  _LISTTICKETSOUTPUT._serialized_end=8315
  _REPLYTICKETINPUT._serialized_start=8317
  _REPLYTICKETINPUT._serialized_end=8386
  _REPLYTICKETOUTPUT._serialized_start=8388
  _REPLYTICKETOUTPUT._serialized_end=8425
  _LISTREPLIESINPUT._serialized_start=8427
  _LISTREPLIESINPUT._serialized_end=8494
  _LISTREPLIESOUTPUT._serialized_start=8496
  _LISTREPLIESOUTPUT._serialized_end=8566
  _DELETEREPLYINPUT._serialized_start=8568
  _DELETEREPLYINPUT._serialized_end=8623
  _DELETEREPLYOUTPUT._serialized_start=8625
  _DELETEREPLYOUTPUT._serialized_end=8644
  _UPDATEREPLYINPUT._serialized_start=8646
  _UPDATEREPLYINPUT._serialized_end=8718
  _UPDATEREPLYOUTPUT._serialized_start=8720
  _UPDATEREPLYOUTPUT._serialized_end=8739
  _CONFIGURERUNTIMEINPUT._serialized_start=8741
  _CONFIGURERUNTIMEINPUT._serialized_end=8801
  _CONFIGURERUNTIMEOUTPUT._serialized_start=8803
  _CONFIGURERUNTIMEOUTPUT._serialized_end=8827
  _DESCRIBERUNTIMEINPUT._serialized_start=8829
  _DESCRIBERUNTIMEINPUT._serialized_end=8871
  _DESCRIBERUNTIMEOUTPUT._serialized_start=8873
  _DESCRIBERUNTIMEOUTPUT._serialized_end=8913
  _CONFIGURESCORINGINPUT._serialized_start=8915
  _CONFIGURESCORINGINPUT._serialized_end=9006
  _CONFIGURESCORINGOUTPUT._serialized_start=9008
  _CONFIGURESCORINGOUTPUT._serialized_end=9032
  _DESCRIBESCORINGINPUT._serialized_start=9034
  _DESCRIBESCORINGINPUT._serialized_end=9076
  _DESCRIBESCORINGOUTPUT._serialized_start=9078
  _DESCRIBESCORINGOUTPUT._serialized_end=9149
  _CREATEANNOUNCEMENTINPUT._serialized_start=9151
  _CREATEANNOUNCEMENTINPUT._serialized_end=9246
  _CREATEANNOUNCEMENTOUTPUT._serialized_start=9248
  _CREATEANNOUNCEMENTOUTPUT._serialized_end=9286
  _UPDATEANNOUNCEMENTINPUT._serialized_start=9288
  _UPDATEANNOUNCEMENTINPUT._serialized_end=9408
  _UPDATEANNOUNCEMENTOUTPUT._serialized_start=9410
  _UPDATEANNOUNCEMENTOUTPUT._serialized_end=9436
  _DELETEANNOUNCEMENTINPUT._serialized_start=9438
  _DELETEANNOUNCEMENTINPUT._serialized_end=9508
  _DELETEANNOUNCEMENTOUTPUT._serialized_start=9510
  _DELETEANNOUNCEMENTOUTPUT._serialized_end=9536
  _READANNOUNCEMENTINPUT._serialized_start=9538
  _READANNOUNCEMENTINPUT._serialized_end=9606
  _READANNOUNCEMENTOUTPUT._serialized_start=9608
  _READANNOUNCEMENTOUTPUT._serialized_end=9632
  _DESCRIBEANNOUNCEMENTINPUT._serialized_start=9634
  _DESCRIBEANNOUNCEMENTINPUT._serialized_end=9706
  _DESCRIBEANNOUNCEMENTOUTPUT._serialized_start=9708
  _DESCRIBEANNOUNCEMENTOUTPUT._serialized_end=9786
  _DESCRIBEANNOUNCEMENTSTATUSINPUT._serialized_start=9788
  _DESCRIBEANNOUNCEMENTSTATUSINPUT._serialized_end=9866
  _DESCRIBEANNOUNCEMENTSTATUSOUTPUT._serialized_start=9868
  _DESCRIBEANNOUNCEMENTSTATUSOUTPUT._serialized_end=9919
  _LISTANNOUNCEMENTSINPUT._serialized_start=9922
  _LISTANNOUNCEMENTSINPUT._serialized_end=10163
  _LISTANNOUNCEMENTSINPUT_FILTER._serialized_start=10060
  _LISTANNOUNCEMENTSINPUT_FILTER._serialized_end=10163
  _LISTANNOUNCEMENTSOUTPUT._serialized_start=10165
  _LISTANNOUNCEMENTSOUTPUT._serialized_end=10248
  _DESCRIBECODETEMPLATEINPUT._serialized_start=10250
  _DESCRIBECODETEMPLATEINPUT._serialized_end=10360
  _DESCRIBECODETEMPLATEOUTPUT._serialized_start=10362
  _DESCRIBECODETEMPLATEOUTPUT._serialized_end=10432
  _LOOKUPCODETEMPLATEINPUT._serialized_start=10434
  _LOOKUPCODETEMPLATEINPUT._serialized_end=10538
  _LOOKUPCODETEMPLATEOUTPUT._serialized_start=10540
  _LOOKUPCODETEMPLATEOUTPUT._serialized_end=10608
  _REBUILDSCOREINPUT._serialized_start=10610
  _REBUILDSCOREINPUT._serialized_end=10649
  _REBUILDSCOREOUTPUT._serialized_start=10651
  _REBUILDSCOREOUTPUT._serialized_end=10692
  _INTROSPECTSCOREINPUT._serialized_start=10694
  _INTROSPECTSCOREINPUT._serialized_end=10736
  _INTROSPECTSCOREOUTPUT._serialized_start=10738
  _INTROSPECTSCOREOUTPUT._serialized_end=10797
  _DESCRIBESCOREINPUT._serialized_start=10800
  _DESCRIBESCOREINPUT._serialized_end=10933
  _DESCRIBESCOREOUTPUT._serialized_start=10935
  _DESCRIBESCOREOUTPUT._serialized_end=10992
  _IMPORTSCOREINPUT._serialized_start=10994
  _IMPORTSCOREINPUT._serialized_end=11093
  _IMPORTSCOREOUTPUT._serialized_start=11095
  _IMPORTSCOREOUTPUT._serialized_end=11114
  _EXPORTSCOREINPUT._serialized_start=11116
  _EXPORTSCOREINPUT._serialized_end=11178
  _EXPORTSCOREOUTPUT._serialized_start=11180
  _EXPORTSCOREOUTPUT._serialized_end=11236
  _LISTRESULTINPUT._serialized_start=11239
  _LISTRESULTINPUT._serialized_end=11375
  _LISTRESULTOUTPUT._serialized_start=11377
  _LISTRESULTOUTPUT._serialized_end=11447
  _LISTACTIVITIESINPUT._serialized_start=11449
  _LISTACTIVITIESINPUT._serialized_end=11520
  _LISTACTIVITIESOUTPUT._serialized_start=11522
  _LISTACTIVITIESOUTPUT._serialized_end=11598
  _CONFIGUREAPPEARANCEINPUT._serialized_start=11600
  _CONFIGUREAPPEARANCEINPUT._serialized_end=11700
  _CONFIGUREAPPEARANCEOUTPUT._serialized_start=11702
  _CONFIGUREAPPEARANCEOUTPUT._serialized_end=11729
  _DESCRIBEAPPEARANCEINPUT._serialized_start=11731
  _DESCRIBEAPPEARANCEINPUT._serialized_end=11776
  _DESCRIBEAPPEARANCEOUTPUT._serialized_start=11778
  _DESCRIBEAPPEARANCEOUTPUT._serialized_end=11858
  _JUDGE._serialized_start=11861
  _JUDGE._serialized_end=25411
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UploadImageInput(_message.Message):
    __slots__ = ["crop", "data", "name", "size", "type", "variants"]
    class Crop(_message.Message):
        __slots__ = ["bottom", "left", "right", "top"]
        BOTTOM_FIELD_NUMBER: _ClassVar[int]
        LEFT_FIELD_NUMBER: _ClassVar[int]
        RIGHT_FIELD_NUMBER: _ClassVar[int]
        TOP_FIELD_NUMBER: _ClassVar[int]
        bottom: int
        left: int
        right: int
        top: int
        def __init__(self, top: _Optional[int] = ..., right: _Optional[int] = ..., bottom: _Optional[int] = ..., left: _Optional[int] = ...) -> None: ...
    class Size(_message.Message):
        __slots__ = ["height", "width"]
        HEIGHT_FIELD_NUMBER: _ClassVar[int]
        WIDTH_FIELD_NUMBER: _ClassVar[int]
        height: int
        width: int
        def __init__(self, width: _Optional[int] = ..., height: _Optional[int] = ...) -> None: ...
    CROP_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    VARIANTS_FIELD_NUMBER: _ClassVar[int]
    crop: UploadImageInput.Crop
    data: bytes
    name: str
    size: UploadImageInput.Size
    type: str
    variants: _containers.RepeatedCompositeFieldContainer[UploadImageInput.Size]
    def __init__(self, name: _Optional[str] = ..., type: _Optional[str] = ..., crop: _Optional[_Union[UploadImageInput.Crop, _Mapping]] = ..., size: _Optional[_Union[UploadImageInput.Size, _Mapping]] = ..., variants: _Optional[_Iterable[_Union[UploadImageInput.Size, _Mapping]]] = ..., data: _Optional[bytes] = ...) -> None: ...

class UploadImageOutput(_message.Message):
    __slots__ = ["image_url"]
    IMAGE_URL_FIELD_NUMBER: _ClassVar[int]
    image_url: str
    def __init__(self, image_url: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Test(_message.Message):
    __slots__ = ["answer_object_id", "example", "id", "index", "input_object_id", "score", "testset_id"]
    ANSWER_OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    EXAMPLE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    INPUT_OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    TESTSET_ID_FIELD_NUMBER: _ClassVar[int]
    answer_object_id: str
    example: bool
    id: str
    index: int
    input_object_id: str
    score: float
    testset_id: str
    def __init__(self, id: _Optional[str] = ..., testset_id: _Optional[str] = ..., index: _Optional[int] = ..., example: bool = ..., score: _Optional[float] = ..., input_object_id: _Optional[str] = ..., answer_object_id: _Optional[str] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.asset import asset_pb2 as _asset_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/ecm/content.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import node_pb2 as eolymp_dot_ecm_dot_node__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x65olymp/ecm/content.proto\x12\neolymp.ecm\x1a\x15\x65olymp/ecm/node.proto\"h\n\x07\x43ontent\x12\x0e\n\x04html\x18\x01 \x01(\tH\x00\x12\x0f\n\x05latex\x18\x02 \x01(\tH\x00\x12\x12\n\x08markdown\x18\x03 \x01(\tH\x00\x12\x1f\n\x03\x65\x63m\x18\x04 \x01(\x0b\x32\x10.eolymp.ecm.NodeH\x00\x42\x07\n\x05valueB)Z\'github.com/eolymp/go-sdk/eolymp/ecm;ecmb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.ecm.content_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\'github.com/eolymp/go-sdk/eolymp/ecm;ecm'
  _CONTENT._serialized_start=63
  _CONTENT._serialized_end=167
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/participant.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/judge/participant.proto\x12\x0c\x65olymp.judge\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdc\x04\n\x0bParticipant\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x03\x65rn\x18\x8fN \x01(\t\x12\x12\n\ncontest_id\x18\x03 \x01(\t\x12\x11\n\tmember_id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x1a\n\x12out_of_competition\x18\x06 \x01(\x08\x12\x30\n\x06status\x18\x14 \x01(\x0e\x32 .eolymp.judge.Participant.Status\x12.\n\nstarted_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nstarted_in\x18\x16 \x01(\r\x12*\n\x06\x65nd_at\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06\x65nd_in\x18\x18 \x01(\r\x12/\n\x0b\x63omplete_at\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x63omplete_in\x18\x1a \x01(\r\x12\x12\n\nbonus_time\x18\x1b \x01(\r\x12\x10\n\x08passcode\x18\x1e \x01(\t\x12\x31\n\x07submits\x18( \x03(\x0b\x32 .eolymp.judge.Participant.Submit\x1a-\n\x06Submit\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\r\"b\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05READY\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03\x12\x0c\n\x08INACTIVE\x10\x04\x12\x10\n\x0cUNREGISTERED\x10\x05\x12\t\n\x05GHOST\x10\x06\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.participant_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _PARTICIPANT._serialized_start=82
  _PARTICIPANT._serialized_end=686
  _PARTICIPANT_SUBMIT._serialized_start=541
  _PARTICIPANT_SUBMIT._serialized_end=586
  _PARTICIPANT_STATUS._serialized_start=588
  _PARTICIPANT_STATUS._serialized_end=686
# @@protoc_insertion_point(module_scope)
